% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/definefuns.R
\name{psim}
\alias{psim}
\title{Simulation of P-approximation}
\usage{
psim(stock, pcoeff)
}
\arguments{
\item{stock}{An array of stock variable}

\item{pcoeff}{An approximation result from \code{paprox} function}
}
\value{
A list of approximation resuts: shadow (accounting) prices and inclusive wealth
}
\description{
The function provides the P-approximation simulation.
}
\details{
Let \eqn{\hat{\beta}} be the approximation coefficent from the results of \code{paprox} function.
The estimated shadow price (accounting) price of stock over the given approximation intervals of
\eqn{s \in [a,b]}, \eqn{\hat{p}} can be calculated as:\cr
\cr
\eqn{\hat{p} = \mathbf{\mu}(s) \mathbf{\hat{\beta}}}.\cr
\cr
The inclusive wealth is:\cr
\cr
\eqn{IW = \hat{p}s }. \cr
\cr
For more detils see Fenichel and Abbott (2014) and Fenichel et al. (2016).
}
\examples{
## 1-D Reef-fish example: see Fenichel and Abbott (2014)
data("reefdata")
st <- reefaproxdata[,1]
sdot <- reefaproxdata[,2]
dsdotds <- reefaproxdata[,3]
dwds <- reefaproxdata[,6]
aproxdeg <- 50
lower <- 5*10^6
upper <- 359016000
delta <- 0.02
reefspace <- aproxdef(aproxdeg,lower,upper,delta)
paproxc <- paprox(st,sdot,dsdotds,dwds,reefspace)

# approximation domain
stapprox <- reefsimdata[,1]
reefsim <- psim(stapprox,paproxc)

# Accounting Price
plot(stapprox,reefsim[["shadowp"]],type='l', lwd=2, col="blue",
     ylim = c(0,30),
     xlab="Stock size, s",
     ylab="Accounting price")

# Inclusive Wealth
plot(stapprox,reefsim[["iw"]],type='l', lwd=2, col="blue",
     xlab="Stock size, s",
     ylab="Inclusive Wealth")
}
\references{
Fenichel, Eli P. and Joshua K. Abbott. (2014) "\href{http://www.journals.uchicago.edu/doi/abs/10.1086/676034}{Natural Capital: From Metaphor to Measurement}."
             \emph{Journal of the Association of Environmental Economists}. 1(1/2):1-27.
}
\seealso{
\code{\link{aproxdef}, \link{paprox}}
}

