#install.packages("path/capn_0.0.2.tar.gz", repos = NULL, type="source")
# replace "path" with your path" 
library(capn)

## 1-D example: Reef Fish example in Fenichel and Abbott (2014)
rm(list=ls())
data("reefdata")

# define variables for collocation
st <- matrix(reefaproxdata[,1], ncol=1)
sdot <- matrix(reefaproxdata[,2], ncol=1)
dsdotds <- reefaproxdata[,3]
dsdotdss <- reefaproxdata[,4]
wval <- reefaproxdata[,5]
dwds <- reefaproxdata[,6]
dwdss <- reefaproxdata[,7]

# define variables for simulation
st1 <- matrix(reefsimdata[,1], ncol=1)
sdot1 <- matrix(reefsimdata[,2], ncol=1)
dsdotds1 <- reefsimdata[,3]
dsdotdss1 <- reefsimdata[,4]
wval1 <- reefsimdata[,5]
dwds1 <- reefsimdata[,6]
dwdss1 <- reefsimdata[,7]

# collocation space
delta <- 0.02
upperK <- 359016000     # upper bound on approximation range
lowerK <- 5*10^6
myspace <- aproxdef(50,lowerK,upperK,delta)

## V-collocation
vaproxc <- vaprox(cbind(st,sdot,wval),myspace)
# attributes(vcolc)
vres <- vsim(st1,vaproxc)
# attributes(vcolres)

## P-collocation
paproxc <- paprox(st,sdot,dsdotds,dwds,myspace)
pres <- psim(st1,paproxc)

## Pdot-collocation
pdotaproxc <- pdotaprox(st,sdot,dsdotds, dsdotdss,dwds, dwdss, myspace)
pdotres <- pdotsim(st1,sdot1,dsdotds1,wval1,dwds1,pdotaproxc)

# three curves in one plot
plot(st1,vres[["shadowp"]],lwd=2, col="red",
     ylim = c(0,15),
     xlab="Stock size, s",
     ylab="Accounting price")
points(st1,vres[["shadowp"]], col="red")
lines(st1,pres[["shadowp"]], lty = 2, lwd=2, col="blue")
points(st1,pres[["shadowp"]], pch="*", col="blue" )
lines(st1,pdotres[["shadowp"]], lty=2, lwd=2, col="green")
legend("topright", c("V-approximation", "P-approximation", "Pdot-approximation"), col=c("red", "blue", "green"), lty=c(1,1,1))


